summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorfredrik-aschehoug <15358786+fredrik-aschehoug@users.noreply.github.com>2021-03-14 17:58:52 +0100
committerfredrik-aschehoug <15358786+fredrik-aschehoug@users.noreply.github.com>2021-03-14 17:58:52 +0100
commita5f39642455aa93974936f02cfd0aa6db83abe49 (patch)
tree5d2e562a61dc273356f03a77d233f2ec9f68d430
parent64d20ebb9ca6aa2703bc5ccabe7fe5a9845696a8 (diff)
downloadrdflib-a5f39642455aa93974936f02cfd0aa6db83abe49.tar.gz
Fix spelling
-rw-r--r--test/test_namespace.py6
-rw-r--r--test/test_turtle_serialize.py6
2 files changed, 6 insertions, 6 deletions
diff --git a/test/test_turtle_serialize.py b/test/test_turtle_serialize.py
index 36ca7465..9e6f0b63 100644
--- a/test/test_turtle_serialize.py
+++ b/test/test_turtle_serialize.py
@@ -98,9 +98,9 @@ def test_turtle_namespace():
)
graph.add(
(
- URIRef("http://example.org/name_with_(parantheses)"),
+ URIRef("http://example.org/name_with_(parenthesis)"),
RDFS.label,
- Literal("URI with parantheses"),
+ Literal("URI with parenthesis"),
)
)
output = [
@@ -112,7 +112,7 @@ def test_turtle_namespace():
assert "RO_has_phenotype:" in output
assert "GENO:0000385" in output
assert "SERIAL:0167-6423" in output
- assert "EX:name_with_(parantheses)" in output
+ assert "EX:name_with_(parenthesis)" in output
if __name__ == "__main__":
diff --git a/test/test_namespace.py b/test/test_namespace.py
index e3be3a1c..3c321f8c 100644
--- a/test/test_namespace.py
+++ b/test/test_namespace.py
@@ -43,10 +43,10 @@ class NamespacePrefixTest(unittest.TestCase):
("ns5", URIRef("urn:ISSN:"), ""),
)
# should compute qnames with parantheses correctly
self.assertEqual(
- g.compute_qname(URIRef("http://foo/bar/name_with_(parantheses)")),
- ("ns1", URIRef("http://foo/bar/"), "name_with_(parantheses)"),
+ g.compute_qname(URIRef("http://foo/bar/name_with_(parenthesis)")),
+ ("ns1", URIRef("http://foo/bar/"), "name_with_(parenthesis)"),
)
def test_reset(self):
@@ -43,10 +43,10 @@ class NamespacePrefixTest(unittest.TestCase):
("ns5", URIRef("urn:ISSN:"), ""),
)
- # should compute qnames with parantheses correctly
+ # should compute qnames with parenthesis correctly
self.assertEqual(